==> redux-1.0.15.tgz: package/lib/immutable/ConnectedBootstrapProvider/tests/index.test.js <==
"use strict";

var _immutable = require("immutable");

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _redux = require("redux");

var _reduxImmutable = require("redux-immutable");

var _reactRedux = require("react-redux");

var _bootstrapStyled = require("bootstrap-styled");

var _Button = _interopRequireDefault(require("@bootstrap-styled/v4/lib/Button"));

var _ = _interopRequireDefault(require(".."));

var _reducer = _interopRequireDefault(require("../../reducer"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable function-paren-newline */
describe('<ConnectedBootstrapProvider />', function () {
  var store;
  beforeAll(function () {
    store = (0, _redux.createStore)((0, _reduxImmutable.combineReducers)({
      'bs.redux': _reducer.default
    }));
  });
  it('should render the ConnectedBootstrapProvider', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_reactRedux.Provider, {
      store: store
    }, _react.default.createElement(_.default, {
      injectGlobal: false,
      reset: false
    }, _react.default.createElement(_Button.default, null, "Hey"))));
    expect(renderedComponent.contains(_react.default.createElement(_Button.default, null, "Hey"))).toBe(true);
    expect((0, _immutable.fromJS)(renderedComponent.find('BootstrapProvider').prop('theme')).hashCode()).toBe((0, _immutable.fromJS)(_bootstrapStyled.theme).hashCode());
  });
});
/* eslint-enable function-paren-newline */

==> redux-1.1.1.tgz: package/lib/immutable/ConnectedBootstrapProvider/tests/index.test.js <==
"use strict";

var _immutable = require("immutable");

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _redux = require("redux");

var _reduxImmutable = require("redux-immutable");

var _reactRedux = require("react-redux");

var _bootstrapStyled = require("bootstrap-styled");

var _Button = _interopRequireDefault(require("@bootstrap-styled/v4/lib/Button"));

var _ = _interopRequireDefault(require(".."));

var _reducer = _interopRequireDefault(require("../../reducer"));

var _constants = require("../../../constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* eslint-disable function-paren-newline */
describe('<ConnectedBootstrapProvider />', function () {
  var store;
  beforeAll(function () {
    store = (0, _redux.createStore)((0, _reduxImmutable.combineReducers)(_defineProperty({}, _constants.REDUX_BS_KEY, _reducer.default)));
  });
  it('should render the ConnectedBootstrapProvider', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_reactRedux.Provider, {
      store: store
    }, _react.default.createElement(_.default, {
      injectGlobal: false,
      reset: false
    }, _react.default.createElement(_Button.default, null, "Hey"))));
    expect(renderedComponent.contains(_react.default.createElement(_Button.default, null, "Hey"))).toBe(true);
    expect((0, _immutable.fromJS)(renderedComponent.find('BootstrapProvider').prop('theme')).hashCode()).toBe((0, _immutable.fromJS)(_bootstrapStyled.theme).hashCode());
  });
});
/* eslint-enable function-paren-newline */
